$enable-rounded: false;
@import "node_modules/bootstrap/scss/bootstrap";


body,
#root {
    height: 100vh;
    width: 100vw;
}

[data-bs-theme="dark"] {
    --bs-body-bg: #1a1a1a;
    --bs-border-color: #2d2d2d;
}

a {
    text-decoration: none;
}